@@ -46,7 +46,7 @@ import sys
 from typing import TYPE_CHECKING
 
 
-__version__ = "1.3.2"
+__version__ = "1.3.5"
 
 # Alphabetical order of definitions is ensured in tests
 # WARNING: any comment added in this dictionary definition will be lost when
@@ -63,6 +63,8 @@ _SUBMOD_ATTRS = {
         "InferenceEndpointType",
     ],
     "_jobs_api": [
+        "JobAccelerator",
+        "JobHardware",
         "JobInfo",
         "JobOwner",
         "JobStage",
@@ -241,6 +243,7 @@ _SUBMOD_ATTRS = {
         "list_inference_catalog",
         "list_inference_endpoints",
         "list_jobs",
+        "list_jobs_hardware",
         "list_lfs_files",
         "list_liked_repos",
         "list_models",
@@ -705,6 +708,8 @@ __all__ = [
     "InferenceEndpointTimeoutError",
     "InferenceEndpointType",
     "InferenceTimeoutError",
+    "JobAccelerator",
+    "JobHardware",
     "JobInfo",
     "JobOwner",
     "JobStage",
@@ -925,6 +930,7 @@ __all__ = [
     "list_inference_catalog",
     "list_inference_endpoints",
     "list_jobs",
+    "list_jobs_hardware",
     "list_lfs_files",
     "list_liked_repos",
     "list_models",
@@ -1119,6 +1125,8 @@ if TYPE_CHECKING:  # pragma: no cover
         InferenceEndpointType,  # noqa: F401
     )
     from ._jobs_api import (
+        JobAccelerator,  # noqa: F401
+        JobHardware,  # noqa: F401
         JobInfo,  # noqa: F401
         JobOwner,  # noqa: F401
         JobStage,  # noqa: F401
@@ -1293,6 +1301,7 @@ if TYPE_CHECKING:  # pragma: no cover
         list_inference_catalog,  # noqa: F401
         list_inference_endpoints,  # noqa: F401
         list_jobs,  # noqa: F401
+        list_jobs_hardware,  # noqa: F401
         list_lfs_files,  # noqa: F401
         list_liked_repos,  # noqa: F401
         list_models,  # noqa: F401
